import { ConstructFactory, ConstructFactoryGetInstanceProps, ResourceProvider } from '@aws-amplify/plugin-types';
import { AmplifyStorage, StorageResources } from './construct.js';
import { AmplifyStorageFactoryProps } from './types.js';
import { IAspect } from 'aws-cdk-lib';
import { IConstruct } from 'constructs';
/**
 * Singleton factory for a Storage bucket that can be used in `resource.ts` files
 */
export declare class AmplifyStorageFactory implements ConstructFactory<ResourceProvider<StorageResources>> {
    private readonly props;
    private readonly importStack;
    static hasDefault: boolean;
    static factoryCounter: number;
    static validated: boolean;
    private generator;
    /**
     * Set the properties that will be used to initialize the bucket
     */
    constructor(props: AmplifyStorageFactoryProps, importStack?: string | undefined);
    /**
     * Get a singleton instance of the Bucket
     */
    getInstance: (getInstanceProps: ConstructFactoryGetInstanceProps) => AmplifyStorage;
}
/**
 * StorageValidator class implements the IAspect interface.
 */
export declare class StorageValidator implements IAspect {
    private readonly stack;
    /**
     * Constructs a new instance of the StorageValidator class.
     * @param stack The stack to validate.
     */
    constructor(stack: IConstruct);
    /**
     * Visit method to perform validation on the given node.
     * @param node The IConstruct node to visit.
     */
    visit(node: IConstruct): void;
}
/**
 * Include storage in your Amplify backend.
 * @see https://docs.amplify.aws/gen2/build-a-backend/storage/
 */
export declare const defineStorage: (props: AmplifyStorageFactoryProps) => ConstructFactory<ResourceProvider<StorageResources>>;
//# sourceMappingURL=factory.d.ts.map